<template>
  <div class="container-fluid">
    <!-- دسته‌بندی‌ها -->
    <div class="row text-center p-2 py-2 pb-0" style="background-color: #f7f7f7">
      <nuxt-link
          :to="'/category?category=' + category.name"
          class="col-3 px-0 py-2"
          v-for="category in categories"
          :key="category.id"
      >
        <div class="rounded-3 hover-effect d-flex align-items-center justify-content-center flex-column cursor-pointer">
         <div class="bg-white p-1 border w-70-px h-65-px rounded">
           <img
               :src="category.image"
               :alt="category.name"
               class="img-fluid category-icon max-w-50-px max-h-50-px object-fit-contain"
           />
         </div>
          <p class="small fw-medium font-size-10 text-dark m-0">{{ category.name }}</p>
        </div>
      </nuxt-link>
    </div>


    <!-- مودال فیلتر -->
    <modal-filter @setFilter="setFilter"/>

    <MySwiperWebApp class="my-2"/>

    <!-- فیلتر -->
    <div class="row mt-1 mb-3">
      <div class="align-middle">
        <div class="d-flex justify-content-end">
<!--          <nuxt-link-->
<!--              to="/campaign"-->
<!--              class="btn btn-sm px-1 campaign-btn fw-bold d-flex align-items-center justify-content-center font-size-12"-->
<!--          >-->
<!--            لیست کمپین ها-->
<!--          </nuxt-link>-->

          <nuxt-link
              to="/page/ai"
              class="btn btn-sm px-1 ai-btn fw-bold d-flex align-items-center justify-content-center font-size-12"
          >
            <div class="spinner-grow text-white w-10-px h-10-px mx-2" role="status">
              <span class="visually-hidden">Loading...</span>
            </div>
            {{ t('index.ai_page') }}
          </nuxt-link>
        </div>
<!--        <campaign-list />-->
      </div>
    </div>


    <!-- لیست آگهی‌ها با استفاده از کامپوننت جدید -->
    <div class="pb-5 mb-5">
      <template v-if="data.advertises.length > 0">
        <div class="row border-top">
          <template v-for="(advertise, index) in data.advertises" :key="index">
            <div class="col-12">
              <advertise-item :data="advertise"/>
            </div>

            <!-- درج اسلایدر بعد از هر 20 آگهی (و فقط بین آگهی‌ها) -->
            <!-- <div v-if="(index + 1) % 20 === 0" class="col-12 my-4">
              <MySwiperWebApp />
            </div> -->
<!--            <div v-if="index === 19" class="my-4">-->
<!--             <BannerSingle/>-->
<!--            </div>-->
          </template>
        </div>
      </template>
      <template v-else>
        <template v-if="data.loaded">
          <div class="row mt-5">
            <div class="col-12">
              <div class="d-flex align-items-center justify-content-center flex-column py-1">
                <i class="icon icon-regular-papers-text text-muted" style="font-size: 3rem;"></i>
                <h5 class="mt-3 text-center text-secondary">{{ t("account.advertise.empty.title") }}</h5>
              </div>
            </div>
          </div>
        </template>
      </template>

      <template v-if="!data.loaded">
        <loaded-account-advertise />
      </template>

      <div class="fixed-bottom" style="bottom: 12%;right: 3%;">
        <button
            class="btn btn-sm px-1 filter-btn rounded-circle fw-bold d-flex align-items-center justify-content-center font-size-12"
            data-bs-toggle="modal"
            data-bs-target="#filterModal"
        >
          <i class="icon icon-regular-filter text-white font-size-16"></i>
          {{ t('index.filter_button') }}
        </button>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n';
import {onBeforeUnmount, onMounted, reactive, watch} from "vue";
import {useRoute, useRouter} from "vue-router";
import {useFilterStore} from "~/stores/data/filter";

// Variable
const {t} = useI18n();
const route = useRoute();
const router = useRouter();
const filter = useFilterStore();
const {$api} = useNuxtApp();

// Data
const data = reactive({
  loaded: true,
  advertises: [],
  page: 1,
  search: "",
  meta: {}
});

const categories = [
  {id: 1, name: "املاک", image: "/category/amlak.png"},
  {id: 2, name: "وسایل نقلیه", image: "/category/car.png"},
  {id: 3, name: "خانه و آشپزخانه", image: "/category/home&kitchen.png"},
  {id: 4, name: "کالای دیجیتال", image: "/category/digital.png"},
  {id: 5, name: "غرفه‌ی من", image: "/category/exhibitions.png"},
  {id: 6, name: "خدمات", image: "/category/services.png"},
  {id: 7, name: "آثار هنری", image: "/category/art.svg"},
  {id: 8, name: "نمایشگاه ها", image: "/category/myBooth.png"},
];

// Actions
const setFilter = () => {
  data.page = 1;
  data.advertises = [];
  getData();
  window.scrollTo({top: 0, behavior: 'smooth'});
};

const getData = async () => {
  data.loaded = false;
  await $api.post("/advertise", {
    search: data.search,
    page: data.page,
    ...filter.$state
  }).then((value) => {
    data.advertises.push(...value.data.data);

    data.meta = value.data.meta;

    setTimeout(() => {
      data.loaded = true;
    },100);
  });
};

const isBottomOfPage = () => {
  return window.innerHeight + window.scrollY >= document.documentElement.scrollHeight - 500;
};

const handleScroll = () => {
  if (isBottomOfPage() && data.loaded && data.page < data.meta.last_page) {
    data.page++;
    getData();
  }
};

// Life Cycle
onMounted(() => {
  if(typeof route.query.query !== 'undefined') {
    data.search = route.query.query;
    data.page = 1;
    data.advertises = [];
    getData();
    window.scrollTo({top: 0, behavior: 'smooth'});
  }
  filter.resetFilter();
  getData();
  window.addEventListener('scroll', handleScroll);
});

onBeforeUnmount(() => {
  window.removeEventListener('scroll', handleScroll);
});

watch(() => route.query.query, (newQuery, oldQuery) => {
  if (newQuery !== oldQuery) {
    data.search = newQuery || "";
    data.page = 1;
    data.advertises = [];
    getData();
    window.scrollTo({top: 0, behavior: 'smooth'});
  }
});

</script>

<style scoped>

</style>